# 文本字段

Joe 在设计订单表，他已经完成了下列内容：

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    ts timestamp default now()
);
```

现在他需要给订单表加入一个 description 字段，这个字段需要保存订单的文字说明，这些文本不会超过两千字节， Joe 应该把建表语句修改为：

## 答案

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    description text,
    ts timestamp default now()
);
```

## 选项

### A

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    description char(2000),
    ts timestamp default now()
);
```

### B

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    description varchar(256) default '',
    ts timestamp default now()
);
```

### C

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    description text(2000),
    ts timestamp default now()
);
```

### D

```postgresql
create table orders (
    id serial primary key,
    item_id int,
    amount int,
    unit_price money,
    price money,
    description tinytext(2000),
    ts timestamp default now()
);
```